@@ -5,13 +5,13 @@ from ..baseviews import BaseView, expose
 
 
 class LocaleView(BaseView):
-    route_base = '/lang'
+    route_base = "/lang"
 
-    default_view = 'index'
+    default_view = "index"
 
-    @expose('/<string:locale>')
+    @expose("/<string:locale>")
     def index(self, locale):
-        session['locale'] = locale
+        session["locale"] = locale
         refresh()
         self.update_redirect()
         return redirect(self.get_redirect())
